@@ -59,20 +59,10 @@ namespace Oxygen
 
     //__________________________________________________________________
     StyleConfig::StyleConfig(QWidget* parent):
-        QWidget(parent),
-        _expertMode( false ),
-        _animationConfigWidget(0)
+        QWidget(parent)
     {
         setupUi(this);
 
-        // connections
-        connect( _expertModeButton, SIGNAL(pressed()), SLOT(toggleExpertModeInternal()) );
-
-        _expertModeButton->setIcon( QIcon::fromTheme( QStringLiteral( "configure" ) ) );
-
-        // toggle expert mode
-        toggleExpertModeInternal( false );
-
         // load setup from configData
         load();
 
@@ -80,7 +70,6 @@ namespace Oxygen
         connect( _toolBarDrawItemSeparator, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
         connect( _splitterProxyEnabled, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
         connect( _mnemonicsMode, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()) );
-        connect( _animationsEnabled, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
         connect( _viewDrawFocusIndicator, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
         connect( _viewTriangularExpanderSize, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()) );
         connect( _viewDrawTreeBranchLines, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
@@ -92,6 +81,7 @@ namespace Oxygen
         connect( _menuHighlightSubtle, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
         connect( _windowDragMode, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()) );
 
+
     }
 
     //__________________________________________________________________
@@ -110,16 +100,7 @@ namespace Oxygen
         StyleConfigData::setMenuHighlightMode( menuMode() );
         StyleConfigData::setWindowDragMode( _windowDragMode->currentIndex()  );
 
-        if( _expertMode )
-        {
-
-            _animationConfigWidget->save();
-
-        } else {
-
-            StyleConfigData::setAnimationsEnabled( _animationsEnabled->isChecked() );
-
-        }
+        _animationConfigWidget->save();
 
         #if OXYGEN_USE_KDE4
         StyleConfigData::self()->writeConfig();
@@ -162,106 +143,6 @@ namespace Oxygen
         load();
     }
 
-    //__________________________________________________________________
-    void StyleConfig::toggleExpertMode( bool value )
-    {
-        _expertModeContainer->hide();
-        toggleExpertModeInternal( value );
-    }
-
-    //__________________________________________________________________
-    void StyleConfig::toggleExpertModeInternal( bool value )
-    {
-
-        // store value
-        _expertMode = value;
-
-        // update button text
-        _expertModeButton->setText( _expertMode ? i18n( "Hide Advanced Configuration Options" ):i18n( "Show Advanced Configuration Options" ) );
-
-        // update widget visibility based on expert mode
-        if( _expertMode )
-        {
-
-            // create animationConfigWidget if needed
-            if( !_animationConfigWidget )
-            {
-                _animationConfigWidget = new AnimationConfigWidget();
-                _animationConfigWidget->installEventFilter( this );
-                connect( _animationConfigWidget, SIGNAL(changed(bool)), SLOT(updateChanged()) );
-                connect( _animationConfigWidget, SIGNAL(layoutChanged()), SLOT(updateLayout()) );
-                _animationConfigWidget->load();
-            }
-
-            // add animationConfigWidget to tabbar if needed
-            if( tabWidget->indexOf( _animationConfigWidget ) < 0 )
-            { tabWidget->insertTab( 1, _animationConfigWidget, i18n( "Animations" ) ); }
-
-        } else if( _animationConfigWidget ) {
-
-            if( int index = tabWidget->indexOf( _animationConfigWidget ) >= 0 )
-            { tabWidget->removeTab( index ); }
-
-        }
-
-        _mnemonicsLabel->setVisible( _expertMode );
-        _mnemonicsMode->setVisible( _expertMode );
-        _animationsEnabled->setVisible( !_expertMode );
-        _viewsExpertWidget->setVisible( _expertMode );
-
-        updateMinimumSize();
-
-    }
-
-    //__________________________________________________________________
-    bool StyleConfig::eventFilter( QObject* object, QEvent* event )
-    {
-
-        switch( event->type() )
-        {
-
-            case QEvent::ShowToParent:
-            object->event( event );
-            updateLayout();
-            return true;
-
-            default:
-            return false;
-        }
-    }
-
-    //__________________________________________________________________
-    bool StyleConfig::event( QEvent* event )
-    {
-        const bool result( QWidget::event( event ) );
-        switch( event->type() )
-        {
-            case QEvent::Show:
-            case QEvent::ShowToParent:
-            updateMinimumSize();
-            break;
-
-            default: break;
-        }
-
-        return result;
-
-    }
-
-    //__________________________________________________________________
-    void StyleConfig::updateMinimumSize( void )
-    { setMinimumSize( minimumSizeHint() ); }
-
-    //__________________________________________________________________
-    void StyleConfig::updateLayout( void )
-    {
-        if( _animationConfigWidget )
-        {
-            const int delta = _animationConfigWidget->minimumSizeHint().height() - _animationConfigWidget->size().height();
-            window()->setMinimumSize( QSize( window()->minimumSizeHint().width(), window()->size().height() + delta ) );
-        }
-    }
-
     //__________________________________________________________________
     void StyleConfig::updateChanged()
     {
@@ -278,7 +159,6 @@ namespace Oxygen
         else if( _scrollBarSubLineButtons->currentIndex() != StyleConfigData::scrollBarSubLineButtons() ) modified = true;
         else if( _splitterProxyEnabled->isChecked() != StyleConfigData::splitterProxyEnabled() ) modified = true;
         else if( menuMode() != StyleConfigData::menuHighlightMode() ) modified = true;
-        else if( _animationsEnabled->isChecked() != StyleConfigData::animationsEnabled() ) modified = true;
         else if( _viewDrawFocusIndicator->isChecked() != StyleConfigData::viewDrawFocusIndicator() ) modified = true;
         else if( triangularExpanderSize() != StyleConfigData::viewTriangularExpanderSize() ) modified = true;
         else if( _animationConfigWidget && _animationConfigWidget->isChanged() ) modified = true;
@@ -310,7 +190,6 @@ namespace Oxygen
         _menuHighlightStrong->setChecked( StyleConfigData::menuHighlightMode() == StyleConfigData::MM_STRONG );
         _menuHighlightSubtle->setChecked( StyleConfigData::menuHighlightMode() == StyleConfigData::MM_SUBTLE );
 
-        _animationsEnabled->setChecked( StyleConfigData::animationsEnabled() );
         _windowDragMode->setCurrentIndex( StyleConfigData::windowDragMode() );
 
         _viewDrawFocusIndicator->setChecked( StyleConfigData::viewDrawFocusIndicator() );
